@@ -3,7 +3,7 @@ pub mod zest_dec;
 pub mod zest_digest;
 pub mod zest_enc;
 pub mod zest_hash;
+pub mod zest_pad;
 pub mod zest_rand;
 // Internal usage
 mod num_def;
-mod zest_pad;
