@@ -1,5 +1,5 @@
 use std::num::Wrapping;
-use std::ops::{Add, BitXor, BitXorAssign, Index, IndexMut};
+use std::ops::{BitXor, BitXorAssign, Index, IndexMut};
 
 #[derive(Clone, Copy, PartialEq, Debug)]
 pub struct ZestBlock {
@@ -32,22 +32,6 @@ impl ZestBlock {
     }
 }
 
-//Addition, full block wise.
-impl Add<ZestBlock> for ZestBlock {
-    type Output = ZestBlock;
-    #[inline(always)]
-    fn add(self, rhs: ZestBlock) -> Self::Output {
-        let mut added = self;
-        let mut carry = 0;
-        for (index, chunk) in added.data.iter_mut().enumerate().rev() {
-            *chunk = (Wrapping(*chunk) + Wrapping(carry)).0;
-            carry = (*chunk < carry) as u64;
-            *chunk = (Wrapping(*chunk) + Wrapping(rhs[index])).0;
-            carry += (*chunk < rhs[index]) as u64;
-        }
-        added
-    }
-}
 
 //XOR, bitwise.
 impl BitXor<ZestBlock> for ZestBlock {
